;; Generated package description from counsel.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "counsel" "0.15.1.0.20260214.101027" "Various completion functions using Ivy" '((emacs "24.5") (ivy "0.15.1") (swiper "0.15.1")) :commit "a0f7fc3c0403a957d009f2bdcc248d3bd5fcfe01" :authors '(("Oleh Krehel" . "ohwoeowho@gmail.com")) :maintainer '("Basil L. Contovounesios" . "basil@contovou.net") :keywords '("convenience" "matching" "tools") :url "https://github.com/abo-abo/swiper")
